Stan Math Library: stan/math/rev/core/chainable_alloc.hpp Source File

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

chainable_alloc.hpp
Go to the documentation of this file.
1 #ifndef STAN_MATH_REV_CORE_CHAINABLE_ALLOC_HPP
2 #define STAN_MATH_REV_CORE_CHAINABLE_ALLOC_HPP
3
4 #include <stan/math/rev/core/chainablestack.hpp>
5
6 namespace stan {
7 namespace math {
8
16 class chainable_alloc {
17 public:
18 chainable_alloc() {
19 ChainableStack::var_alloc_stack_.push_back(this);
20 }
21 virtual ~chainable_alloc() { }
22 };
23
24 }
25 }
26 #endif
stan
Definition: log_sum_exp.hpp:8
stan::math::AutodiffStackStorage::var_alloc_stack_
static std::vector< ChainableAllocT * > var_alloc_stack_
Definition: autodiffstackstorage.hpp:15
stan::math::chainable_alloc::~chainable_alloc
virtual ~chainable_alloc()
Definition: chainable_alloc.hpp:21
stan::math::chainable_alloc::chainable_alloc
chainable_alloc()
Definition: chainable_alloc.hpp:18
stan::math::chainable_alloc
A chainable_alloc is an object which is constructed and destructed normally but the memory lifespan i...
Definition: chainable_alloc.hpp:16
chainablestack.hpp

[ Stan Home Page ] © 2011–2016, Stan Development Team.